@@ -3,7 +3,7 @@ package HTML::FormBuilder;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Carp;
 use HTML::FormBuilder::FieldSet;
@@ -684,7 +684,7 @@ the data in the $form will be changed when build the form. So you cannot get the
 
 =head1 AUTHOR
 
-Bond Lim L<kheyeng@my.regentmarkets.com>
+Chylli L<chylli@binary.com>
 
 =head1 COPYRIGHT AND LICENSE
 
